# intake-markdown

`intake-markdown` is a driver for the python library Intake. It allows reading data into a markdown object container that displays nicely in Jupyter Notebook. It is intended to be used to add markdown documentation to intake catalogs. It is based off Intake's `textfile` driver.

